@@ -294,9 +294,6 @@ totem_pl_parser_add_rss (TotemPlParser *parser,
 			 TotemPlParseData *parse_data,
 			 gpointer data)
 {
-#ifndef HAVE_GMIME
-	WARN_NO_GMIME;
-#else
 	xml_node_t* doc, *channel;
 	char *contents;
 	gsize size;
@@ -336,7 +333,6 @@ totem_pl_parser_add_rss (TotemPlParser *parser,
 	xml_parser_free_tree (doc);
 
 	return TOTEM_PL_PARSER_RESULT_SUCCESS;
-#endif /* !HAVE_GMIME */
 }
 
 /* http://www.apple.com/itunes/store/podcaststechspecs.html */
@@ -347,9 +343,6 @@ totem_pl_parser_add_itpc (TotemPlParser *parser,
 			  TotemPlParseData *parse_data,
 			  gpointer data)
 {
-#ifndef HAVE_GMIME
-	WARN_NO_GMIME;
-#else
 	TotemPlParserResult ret;
 	char *uri, *new_uri, *uri_scheme;
 	GFile *new_file;
@@ -368,7 +361,6 @@ totem_pl_parser_add_itpc (TotemPlParser *parser,
 	g_object_unref (new_file);
 
 	return ret;
-#endif /* !HAVE_GMIME */
 }
 
 TotemPlParserResult
@@ -378,9 +370,6 @@ totem_pl_parser_add_zune (TotemPlParser *parser,
 			  TotemPlParseData *parse_data,
 			  gpointer data)
 {
-#ifndef HAVE_GMIME
-	WARN_NO_GMIME;
-#else
 	TotemPlParserResult ret;
 	char *uri, *new_uri;
 	GFile *new_file;
@@ -407,7 +396,6 @@ totem_pl_parser_add_zune (TotemPlParser *parser,
 	g_object_unref (new_file);
 
 	return ret;
-#endif /* !HAVE_GMIME */
 }
 
 /* Atom docs:
@@ -545,9 +533,6 @@ totem_pl_parser_add_atom (TotemPlParser *parser,
 			  TotemPlParseData *parse_data,
 			  gpointer data)
 {
-#ifndef HAVE_GMIME
-	WARN_NO_GMIME;
-#else
 	xml_node_t* doc;
 	char *contents, *uri;
 	gsize size;
@@ -577,7 +562,6 @@ totem_pl_parser_add_atom (TotemPlParser *parser,
 	xml_parser_free_tree (doc);
 
 	return TOTEM_PL_PARSER_RESULT_SUCCESS;
-#endif /* !HAVE_GMIME */
 }
 
 TotemPlParserResult
@@ -587,9 +571,6 @@ totem_pl_parser_add_xml_feed (TotemPlParser *parser,
 			      TotemPlParseData *parse_data,
 			      gpointer data)
 {
-#ifndef HAVE_GMIME
-	WARN_NO_GMIME;
-#else
 	guint len;
 
 	if (data == NULL)
@@ -605,7 +586,6 @@ totem_pl_parser_add_xml_feed (TotemPlParser *parser,
 		return totem_pl_parser_add_opml (parser, file, base_file, parse_data, data);
 
 	return TOTEM_PL_PARSER_RESULT_UNHANDLED;
-#endif /* !HAVE_GMIME */
 }
 
 static char *
@@ -661,9 +641,6 @@ totem_pl_parser_add_itms (TotemPlParser *parser,
 			  TotemPlParseData *parse_data,
 			  gpointer data)
 {
-#ifndef HAVE_GMIME
-	WARN_NO_GMIME;
-#else
 	GFile *json_file, *feed_file;
 	TotemPlParserResult ret;
 	char *contents, *id, *json_uri, *feed_url;
@@ -706,7 +683,6 @@ totem_pl_parser_add_itms (TotemPlParser *parser,
 	g_object_unref (feed_file);
 
 	return ret;
-#endif /* !HAVE_GMIME */
 }
 
 gboolean
@@ -796,9 +772,6 @@ totem_pl_parser_add_opml (TotemPlParser *parser,
 			  TotemPlParseData *parse_data,
 			  gpointer data)
 {
-#ifndef HAVE_GMIME
-	WARN_NO_GMIME;
-#else
 	xml_node_t* doc;
 	char *contents, *uri;
 	gsize size;
@@ -828,7 +801,6 @@ totem_pl_parser_add_opml (TotemPlParser *parser,
 	xml_parser_free_tree (doc);
 
 	return TOTEM_PL_PARSER_RESULT_SUCCESS;
-#endif /* !HAVE_GMIME */
 }
 
 #endif /* !TOTEM_PL_PARSER_MINI */
